#include "mainwindow.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    setWindowTitle(tr("Работа с xml-файлами"));
    QMenuBar* menuBar=new QMenuBar(this);
    QMenu *menu = new QMenu(tr("Меню"),this);
    openAction = new QAction(tr("Открыть"), this);
    closeAction = new QAction(tr("Закрыть всё"), this);
    quitAction = new QAction(tr("Выход"), this);

    menu->addAction(openAction);
    connect(openAction, SIGNAL(triggered()), this, SLOT(openSlot()));

    menu->addAction(closeAction);
    connect(closeAction, SIGNAL(triggered()), this, SLOT(closeSlot()));

    menu->addAction(quitAction);
    connect(quitAction, SIGNAL(triggered()), this, SLOT(quitSlot()));

    menuBar->addMenu(menu);
    myXmlModel=new XmlModel(this);
    myTreeView=new QTreeView(this);
    myTreeView->setModel(myXmlModel);
    setMenuBar(menuBar);
    setCentralWidget(myTreeView);

    myTreeView->setContextMenuPolicy(Qt::CustomContextMenu);
    connect(myTreeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenuCall(QPoint)));
}

MainWindow::~MainWindow() {
    delete myXmlModel;
    delete myTreeView;
}

void MainWindow::openSlot()
{
    QStringList FilesName=QFileDialog::getOpenFileNames(this,tr("Выберите XML-файл(-ы)"),"",tr("XML-файл(*.xml)"));
    myXmlModel->addFiles(FilesName);
    myTreeView->reset();
}

void MainWindow::closeSlot()
{
    delete myXmlModel;
    myXmlModel=new XmlModel(this);
    myTreeView->setModel(myXmlModel);
    myTreeView->reset();
}

void MainWindow::quitSlot()
{
    close();
}

void MainWindow::contextMenuCall(QPoint pos)
{
    if (myTreeView->currentIndex().parent() == myTreeView->rootIndex()) {
        QMenu *menu=new QMenu(this);
        QAction *actionActive = new QAction(tr("Сделать активным"), this);
        connect(actionActive, &QAction::triggered, myXmlModel, &XmlModel::makeActive);
        menu->addAction(actionActive);
        menu->popup(myTreeView->viewport()->mapToGlobal(pos));
    }
}
